﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace DateTimeSeries
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();
            // create sample data
            var data = new ObservableCollection<Series>();

            var years = new DateTime[10];
            var dt = new DateTime(DateTime.Now.Year + 1, 12, 31);
            for (var i = 0; i < 10; i++)
                years[i] = dt.AddYears(-(10 - i));

            var income = new double[10] { 13.2, 15.6, 17.8, 39, 20, 29, 79, 101, 120, 122 };

            var series = new MindFusion.Charting.DateTimeSeries(
                years, income, years[0], years[years.Length - 1]);
            series.MinValue = 0;
            series.MaxValue = 1;
            series.DateTimeFormat = DateTimeFormat.CustomDateTime;
            series.CustomDateTimeFormat = "yyyy";

            data.Add(series);

            // setup chart
            areaChart.BackgroundColor = Color.FromRgb(224, 233, 233);
            areaChart.Series = data;
            areaChart.Title = "Acme Inc. financial report";
            areaChart.ShowXCoordinates = false;
            areaChart.ShowLegend = false;
            areaChart.LayoutPanel.Margin = new Margins(0, 0, 20, 0);

            areaChart.XAxis.Title = "";
            areaChart.XAxis.MinValue = 0;
            areaChart.XAxis.MaxValue = 1;
            areaChart.XAxis.Interval = 0.1;

            areaChart.YAxis.Title = "Income ($ in millions)";

            areaChart.Theme.UniformSeriesFill = new LinearGradientBrush(Color.FromRgb(0, 0, 99), Color.FromRgb(90, 121, 165), 0);
            areaChart.Theme.UniformSeriesStroke = new SolidBrush(Color.FromRgb(0, 52, 102));
            areaChart.Theme.UniformSeriesStrokeThickness = 2;

            areaChart.GridType = GridType.Horizontal;
            areaChart.Theme.GridColor1 = Color.White;
            areaChart.Theme.GridColor2 = Color.FromRgb(240, 240, 240);
            areaChart.Theme.GridLineColor = Color.FromRgb(192, 192, 192);
            areaChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            areaChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            areaChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            areaChart.Theme.AxisStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            areaChart.Theme.DataLabelsFontSize = 12;
            areaChart.Theme.AxisLabelsFontSize = 12;
            areaChart.Theme.AxisTitleFontSize = 14;
            areaChart.Theme.TitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            areaChart.TitleFontSize = 16;
          
        }
    }
}
