﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace LineChart
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();
            // create line brushes
            firstBrush = new SolidBrush(Color.FromRgb(102, 154, 204));
            secondBrush = new SolidBrush(Color.FromRgb(0, 0, 99));
            thirdBrush = new SolidBrush(Color.FromRgb(206, 0, 0));

            lineChart.LegendRenderer.Background = new SolidBrush(Color.FromRgb(235, 235, 235));
            lineChart.BackgroundColor = Colors.White;//.FromRgb(224, 233, 233);
            lineChart.Theme.PlotBackground = Brushes.White;
            lineChart.Theme.GridColor1 = Color.FromRgb(255, 255, 255);
            lineChart.Theme.GridColor1 = Color.FromRgb(245, 245, 245);
            lineChart.Theme.GridLineColor = Colors.Transparent;
            lineChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.AxisStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.DataLabelsFontSize = 12;
            lineChart.Theme.AxisLabelsFontSize = 12;
            lineChart.Theme.AxisTitleFontSize = 14;
            lineChart.Theme.LegendBackground = lineChart.Theme.DataLabelsBackground = Brushes.White;
            lineChart.Theme.LegendBorderStroke = lineChart.Theme.DataLabelsBorderStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            lineChart.Theme.LegendTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));

            // create sample data series
            lineChart.Series.Add(
                new Series2D(
                    new List<double> { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 },
                    new List<double> { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 },
                    labels
                )
                { Title = "Series 1" });

            lineChart.Series.Add(
                new Series2D(
                    new List<double> { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 },
                    new List<double> { 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24 },
                    labels
                )
                { Title = "Series 2" });

            lineChart.Series.Add(
                new FunctionSeries(x => x * Math.Sin(x) + x + 5, 36, 12)
                { Title = "Series 3" });

            lineChart.XAxis.Interval = 1;

            // assign one brush per series
            lineChart.Plot.SeriesStyle = new MixedSeriesStyle
            {
                CommonFills = new List<Brush>
                {
                    firstBrush, secondBrush, thirdBrush
                },
                CommonStrokes = new List<Brush>
                {
                    firstBrush, secondBrush, thirdBrush
                },
                UniformStrokeThickness = 5
            };

            // set up grid type combo box
            cbxGridType.ItemsSource = new[] { GridType.Crossed,
                GridType.Horizontal,
                GridType.None,
                GridType.Vertical };
            cbxGridType.RowHeight = 24;
            cbxGridType.SelectedItem = GridType.Crossed;
            lineChart.GridType = GridType.Crossed;

            // set up line type combo box
            cbxLineType.ItemsSource = new[] { LineType.Polyline,
                LineType.Step,
                LineType.Curve };
            cbxLineType.RowHeight = 24;
            cbxLineType.SelectedItem = LineType.Polyline;
            lineChart.LineType = LineType.Polyline;

            lineChart.ShowXRangeSelector = true;
            lineChart.XScrollRangeMin = -50;
            lineChart.XScrollRangeMax = 50;

            lineChart.ShowYRangeSelector = true;
            lineChart.YScrollRangeMin = -50;
            lineChart.YScrollRangeMax = 50;
        }

        void cbxLineType_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            lineChart.LineType = (LineType)cbxLineType.SelectedItem;
        }

        void cbxGridType_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            lineChart.GridType = (GridType)cbxGridType.SelectedItem;
        }


        List<string> labels = new List<string>
        {
            "one", "two", "three", "four", "five", "six",
            "seven", "eight", "nine", "ten", "eleven", "twelve"
        };

        Brush firstBrush;
        Brush secondBrush;
        Brush thirdBrush;
    }
}