﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace RadarChart
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();

            // create sample data
            radarChart.Series = new ObservableCollection<Series>
            {
                new SimpleSeries(
                    new List<double>
                    {
                        20, 30, 43, 40, 44, 37, 35, 51
                    },
                    new List<string>
                    {
                        "20", "30", "43", "40", "44", "37", "35", "51"
                    }
                ),
                new SimpleSeries(
                    new List<double>
                    {
                        12, 40, 23, 30, 34, 47, 45, 21
                    },
                    new List<string>
                    {
                        "12", "40", "23", "30", "34", "47", "45", "21"
                    }
                )
            };

            // define axis appearance

            radarChart.Theme.AxisLabelsBrush = new SolidBrush(new Color(82, 82, 82));
            radarChart.Theme.AxisLabelsFontSize = 12.0;
            radarChart.Theme.DataLabelsFontSize = 12.0;
            radarChart.Theme.AxisTitleFontSize = 12.0;
            radarChart.Theme.DataLabelsBackground = new SolidBrush(Colors.White);
            radarChart.Theme.AxisStroke = new SolidBrush(Colors.LightGray);
            radarChart.Theme.DataLabelsBrush = radarChart.Theme.DataLabelsBorderStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            radarChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            radarChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            radarChart.AreaOpacity = 0.4;

            radarChart.GridColor1 = Colors.White;
            radarChart.GridColor2 = Color.FromRgb(235, 235, 235);
            
            radarChart.GridDivisions = 5;
            radarChart.DefaultAxis.MinValue = 0;
            radarChart.DefaultAxis.MaxValue = 55;
            radarChart.ShowLegend = false;

            radarChart.BackgroundColor = Color.FromRgb(224, 233, 233);

            for (int i = 0; i < 8; i++)
                radarChart.Axes.Add(new Axis
                {
                    Title = string.Format("Axis {0}", i + 1)
                });

            // fill enumeration combo boxes
            cbxGridType.ItemsSource = new[] {
                RadarGridType.Radar,
                RadarGridType.Spiderweb };
            cbxGridType.SelectedItem = RadarGridType.Spiderweb;
            cbxGridType.RowHeight = 24;

            cbxRadarType.ItemsSource = new[] {
                RadarType.Pie,
                RadarType.Polygon };
            cbxRadarType.SelectedItem = RadarType.Polygon;
            cbxRadarType.RowHeight = 24;

            radarChart.GridType = RadarGridType.Spiderweb;
            radarChart.RadarType = RadarType.Polygon;

            // specify one color per series
            radarChart.Plot.SeriesStyle = new PerSeriesStyle
            {
                Strokes = new List<MindFusion.Drawing.Brush>
                {
                   new SolidBrush(Color.FromRgb(206, 0, 0)),
                   new SolidBrush(Color.FromRgb(45, 57, 86))
                },
                Fills = new List<MindFusion.Drawing.Brush>
                {
                   new SolidBrush(Color.FromRgb(206, 0, 0)),
                   new SolidBrush(Color.FromRgb(45, 57, 86))
                }
            };
        }

        void cbxRadarType_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            radarChart.RadarType = (RadarType)cbxRadarType.SelectedItem;
            radarChart.AreaOpacity = 0.4;
        }

        void cbxGridType_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            radarChart.GridType = (RadarGridType)cbxGridType.SelectedItem;
            radarChart.AreaOpacity = 0.4;
        }
    }
}